@@ -677,7 +677,7 @@ class PySendPulse:
             return self.__handle_error('Seems we have empty subject')
         elif not email.get('from') or not email.get('to'):
             return self.__handle_error("Seems we have empty some credentials 'from': '{}' or 'to': '{}' fields".format(email.get('from'), email.get('to')))
-        email['html'] = base64.b64encode(email.get('html').encode('utf-8')).decode('utf-8')
+        email['html'] = base64.b64encode(email.get('html').encode('utf-8')).decode('utf-8') if email['html'] else None
         return self.__handle_result(self.__send_request('smtp/emails', 'POST', {'email': json.dumps(email)}))
 
     def smtp_send_mail_with_template(self, email):
@@ -870,7 +870,7 @@ class PySendPulse:
 
         @return: dictionary with response message
         """
-        if not addressbook_id or not phones or variables:
+        if not addressbook_id or not phones or not variables:
             return self.__handle_error("Empty addressbook id or phones or variables")
         try:
             phones = json.dumps(phones)
